@@ -1,202 +1,165 @@
-#!/bin/false
-# ABSTRACT: A client for the Bugzilla web services API.
-# PODNAME: BZ::Client
-
-use strict;
-use warnings 'all';
+#
+# BZ::Client.pm - Web services client for the Bugzilla server
+#
 
 package BZ::Client;
-$BZ::Client::VERSION = '1.062_2';
+
 use BZ::Client::XMLRPC();
 use HTTP::Cookies();
 
-sub new {
+our $VERSION = '1.01';
+
+
+sub new($%) {
     my $class = shift;
-    my $self  = {@_};
-    bless( $self, ref($class) || $class );
+    my $self = { @_ };
+    bless($self, ref($class) || $class);
     return $self;
 }
 
-sub url {
+sub url($;$) {
     my $self = shift;
     if (@_) {
         $self->{'url'} = shift;
-    }
-    else {
+    } else {
         return $self->{'url'};
     }
 }
 
-sub user {
+sub user($;$) {
     my $self = shift;
     if (@_) {
         $self->{'user'} = shift;
-    }
-    else {
+    } else {
         return $self->{'user'};
     }
 }
 
-sub password {
+sub password($;$) {
     my $self = shift;
     if (@_) {
         $self->{'password'} = shift;
-    }
-    else {
+    } else {
         return $self->{'password'};
     }
 }
 
-sub error {
-    my ( $self, $message, $http_code, $xmlrpc_code ) = @_;
+sub error($$;$$) {
+    my($self, $message, $http_code, $xmlrpc_code) = @_;
     require BZ::Client::Exception;
-    BZ::Client::Exception->throw(
-        message     => $message,
-        http_code   => $http_code,
-        xmlrpc_code => $xmlrpc_code
-    );
+    BZ::Client::Exception->throw(message => $message,
+                                 http_code => $http_code,
+                                 xmlrpc_code => $xmlrpc_code);
 }
 
-sub log {
-    my ( $self, $level, $msg ) = @_;
+sub log($$$) {
+    my($self, $level, $msg) = @_;
     my $logger = $self->logger();
     if ($logger) {
-        &$logger( $level, $msg );
+        &$logger($level, $msg);
     }
 }
 
-sub logger {
-    my ($self) = shift;
+sub logger($;$) {
+    my($self) = shift;
     if (@_) {
         $self->{'logger'} = shift;
-    }
-    else {
+    } else {
         return $self->{'logger'};
     }
 }
 
-sub logDirectory {
-    my ($self) = shift;
+sub logDirectory($;$) {
+    my($self) = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
-    }
-    else {
+    } else {
         return $self->{'logDirectory'};
     }
 }
 
-sub xmlrpc {
+sub xmlrpc($;$) {
     my $self = shift;
     if (@_) {
         $self->{'xmlrpc'} = shift;
-    }
-    else {
+    } else {
         my $xmlrpc = $self->{'xmlrpc'};
-        if ( !$xmlrpc ) {
-            my $url = $self->url()
-              || $self->error('The Bugzilla servers URL is not set.');
-            $xmlrpc = BZ::Client::XMLRPC->new( 'url' => $url );
-            $xmlrpc->logDirectory( $self->logDirectory() );
-            $xmlrpc->logger( $self->logger() );
+        if (!$xmlrpc) {
+            my $url = $self->url() || $self->error("The Bugzilla servers URL is not set.");
+            $xmlrpc = BZ::Client::XMLRPC->new("url" => $url);
+            $xmlrpc->logDirectory($self->logDirectory());
+            $xmlrpc->logger($self->logger());
             $self->xmlrpc($xmlrpc);
         }
         return $xmlrpc;
     }
 }
 
-sub login {
+sub login($) {
     my $self = shift;
-    my $user = $self->user()
-      or $self->error('The Bugzilla servers user name is not set.');
-    my $password = $self->password()
-      or $self->error('The Bugzilla servers password is not set.');
+    my $user = $self->user() || $self->error("The Bugzilla servers user name is not set.");
+    my $password = $self->password() || $self->error("The Bugzilla servers password is not set.");
 
-    my $params = {
-        'login'    => $user,
-        'password' => $password,
-        'remember' => BZ::Client::XMLRPC::boolean->new(0)
-    };
+    my $params = { "login" => $user,
+                   "password" => $password,
+                   "remember" => BZ::Client::XMLRPC::boolean->new(0) };
     my $cookies = HTTP::Cookies->new();
-    my $response = $self->_api_call( 'User.login', $params, $cookies );
-    if ( not defined( $response->{'id'} )
-        or $response->{'id'} !~ m/^\d+$/s )
-    {
-        $self->error('Server did not return a valid user ID.');
+    my $response = $self->_api_call("User.login", $params, $cookies);
+    if (!defined($response->{'id'})  ||  $response->{'id'} !~ /^\d+$/s) {
+        $self->error("Server did not return a valid user ID.");
     }
-    $self->{'cookies'} = $cookies;
-
+    $self->{"cookies"} = $cookies;
     return;
 }
 
-sub logout {
-    my $self    = shift;
-    my $cookies = $self->{'cookies'};
+sub logout($) {
+    my $self = shift;
+    my $cookies = $self->{"cookies"};
     if ($cookies) {
-        $self->{'cookies'} = undef;
+        $self->{"cookies"} = undef;
         my $xmlrpc = $self->xmlrpc();
-        $xmlrpc->request( 'methodName' => 'User.logout', params => [] );
+        $xmlrpc->request("methodName" => "User.logout", params => [] );
     }
 }
 
-sub is_logged_in {
+sub is_logged_in($) {
     my $self = shift;
-    return ( $self->{'cookies'} or $self->{'payload'} ) ? 1 : 0;
+    return $self->{"cookies"} ? 1 : 0;
 }
 
-sub api_call {
-    my ( $self, $methodName, $params ) = @_;
-    if ( !$self->is_logged_in() ) {
+sub api_call($$$) {
+    my($self, $methodName, $params) = @_;
+    if (!$self->is_logged_in()) {
         $self->login();
     }
-    return $self->_api_call( $methodName, $params );
+    return $self->_api_call($methodName, $params);
 }
 
-sub _api_call {
-
-    my ( $self, $methodName, $params, $cookies ) = @_;
-
-    $self->log( 'debug',
-        "BZ::Client::_api_call, sending request for method $methodName to "
-          . $self->url() );
-
+sub _api_call($$$;$) {
+    my($self, $methodName, $params, $cookies) = @_;
+    $self->log("debug", "BZ::Client::_api_call, sending request for method $methodName to " . $self->url());
     my $xmlrpc = $self->xmlrpc();
-
     if ($cookies) {
         $xmlrpc->user_agent()->cookie_jar($cookies);
     }
-
-    my $response =
-      $xmlrpc->request( 'methodName' => $methodName, params => [$params] );
-
-    if ( not $response ) {
-        $self->error('Empty response from server.');
+    my $response = $xmlrpc->request("methodName" => $methodName, params => [ $params ] );
+    if (!$response) {
+        $self->error("Empty response from server.");
     }
-
-    if ( ref($response) ne 'HASH' ) {
+    if (ref($response) ne "HASH") {
         $self->error("Invalid response from server: $response");
     }
-
-    $self->log( 'debug',
-        "BZ::Client::_api_call, got response for method $methodName" );
-
+    $self->log("debug", "BZ::Client::_api_call, got response for method $methodName");
     return $response;
 }
 
 1;
 
-__END__
-
 =pod
 
-=encoding UTF-8
-
 =head1 NAME
 
-BZ::Client - A client for the Bugzilla web services API.
-
-=head1 VERSION
-
-version 1.062_2
+  BZ::Client - A client for the Bugzilla web services API.
 
 =head1 SYNOPSIS
 
@@ -219,10 +182,6 @@ The new method constructs a new instance of BZ::Client. Whenever you
 want to connect to the Bugzilla server, you must first create a
 Bugzilla client. The methods input is a hash of parameters.
 
-For debuggign, you can pass in a subref named I<logger> which will be
-fed debugging information as the client works. Also the I<logDirectory>
-option is a directory where the raw http content will be dumped.
-
 =over
 
 =item url
@@ -282,27 +241,5 @@ hash ref of named result objects.
 
 =head1 SEE ALSO
 
-L<BZ::Client::Exception>
-
-=head1 AUTHORS
-
-=over 4
-
-=item *
-
-Dean Hamstead <dean@bytefoundry.com.au>
-
-=item *
-
-Jochen Wiedmann <jochen.wiedmann@gmail.com>
-
-=back
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2015 by Dean Hamstad.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+  L<BZ::Client::Exception>
+  
